-- Parser is standalone so that it does not depend on mounted
local L = LibStub("AceLocale-3.0"):GetLocale("MNT2", false)

local MOUNT_GROUND = 'ground'
local MOUNT_FLYING = 'flying'
local MOUNT_WATER = 'water'
local MOUNT_AQ = 'aq'

local SPEED_SLOW = {
	[MOUNT_GROUND] = 60,
	[MOUNT_FLYING] = 60,
}
local SPEED_MEDIUM = {
	[MOUNT_GROUND] = 100,
	[MOUNT_FLYING] = 280,
}
local SPEED_FAST = {
	[MOUNT_FLYING] = 310,
}

local mountBypass = {
	[54729] = {MOUNT_FLYING, 60, MOUNT_FLYING, 280}, -- Winged Steed of the Ebon Blade
	[58983] = {MOUNT_GROUND, 60, MOUNT_GROUND, 100}, -- Big Blizzard Bear
	[48025] = {MOUNT_GROUND, 60, MOUNT_GROUND, 100, MOUNT_FLYING, 60, MOUNT_FLYING, 280}, -- Headless Horseman's Mount
	[30174] = {MOUNT_GROUND, 0}, -- Turtle Mount TCG
	[64731] = {MOUNT_GROUND, 0, MOUNT_WATER, 60}, -- Turtle Mount Fishing
	[25953] = {MOUNT_AQ, 100}, -- Blue Qiraji Battle Tank
	[26056] = {MOUNT_AQ, 100}, -- Green Qiraji Battle Tank
	[26054] = {MOUNT_AQ, 100}, -- Red Qiraji Battle Tank
	[26055] = {MOUNT_AQ, 100}, -- Yellow Qiraji Battle Tank
	[59976] = {MOUNT_FLYING, 310}, --Black Proto-Drake
	[60021] = {MOUNT_FLYING, 310}, --Plagued Proto-Drake
	[60024] = {MOUNT_FLYING, 310}, --Violet Proto-Drake
	[40192] = {MOUNT_FLYING, 310}, --Ashes of Al'ar
	[63963] = {MOUNT_FLYING, 310}, --Rusted Proto-Drake
	[579] = {MOUNT_GROUND, 100}, --Red Wolf
}

local Scanner = CreateFrame("GameTooltip", "MNT_ScannerTooltip", nil, "GameTooltipTemplate")
Scanner:SetOwner(UIParent, "ANCHOR_NONE")
for i = 1, 30 do
	Scanner[i] = _G["MNT_ScannerTooltipTextLeft"..i]
	if not Scanner[i] then
		Scanner[i] = Scanner:CreateFontString()
		Scanner:AddFontStrings(Scanner[i], Scanner:CreateFontString())
	end
end

local mountscancache = {}
 setmetatable(mountscancache, {__mode = "kv"}) -- can GC the cache if it wants to no need for it unless you make frequent calls with the same spellid to this function
function MNT2:GetMountType(spellid)
	if mountscancache[spellid] then
		return unpack(mountscancache[spellid])
	elseif( mountBypass[spellid] ) then
		return unpack(mountBypass[spellid])
	else
		local mountpack = {} -- odd numbers are mount types evens are speeds multible once mean scaling mounts
		Scanner:ClearLines()
		Scanner:SetHyperlink("spell:"..spellid)
		local _, _, Outland, Northrend = GetMapContinents()
		local numLines = Scanner:NumLines()
		local text = ""
		for i=1,numLines do
			text = string.format("%s %s", text, Scanner[i]:GetText())
		end
		if text:match(Outland) or text:match(Northrend) then
			mountpack[1] = MOUNT_FLYING
		else
			mountpack[1] = MOUNT_GROUND
		end
		if text:match(L.SpeedFast) then
			mountpack[2] = SPEED_FAST[mountpack[1]]
		elseif text:match(L.SpeedMedium) then
			mountpack[2] = SPEED_MEDIUM[mountpack[1]]
		else
			mountpack[2] = SPEED_SLOW[mountpack[1]]
		end
		mountscancache[spellid] = mountpack
		return unpack(mountpack)
	end
end
